@@ -253,17 +253,15 @@ async def on_message(message):
                         song_name = random.randint(1, 1000)
                         if platform.system() == "Windows":
                             command_dict[c]["source_to_play"] = f"{dir_path}\{song_name}.mp3"
-                            if "Usage" not in subprocess.getoutput("youtube-dl"):
-                                if "Usage" not in subprocess.getoutput(r"C:\Users\knowl\Downloads\Youtube-Dl\youtube-dl.exe"):
-                                    print("Please install YouTube-dl to play music.")
-                                    return
-                            subprocess.call(f"youtube-dl --extract-audio --audio-format mp3 -o {dir_path}\{song_name}.mp3 \"ytsearch:{message.content.split(' ')[1]}\"", shell=True)
+                            ytl = youtube_dl.YoutubeDL({"outtmpl" : f"{dir_path}\{song_name}.mp3", "format" : "bestaudio"})
+                            ytl.download([f"ytsearch:{message.content.split(' ')[1:]}"])
                         if platform.system() != "Windows":
                             command_dict[c]["source_to_play"] = f"{dir_path}/{song_name}.mp3"
-                            if "Usage" in subprocess.getoutput("youtube-dl"):
+                            if "Usage" not in subprocess.getoutput("youtube-dl"):
                                 print("Please install Youtube-dl to continue")
                                 return
-                            subprocess.call(f"/usr/bin/python3 /usr/local/bin/youtube-dl --extract-audio --audio-format mp3 -o {dir_path}/{song_name}.mp3 \"ytsearch:{message.content.split(' ')[1:]}\"", shell=True)
+                            ytl = youtube_dl.YoutubeDL({"outtmpl" : f"{dir_path}/{song_name}.mp3", "format" : "bestaudio"})
+                            ytl.download([f"ytsearch:{message.content.split(' ')[1:]}"])
 
                     channel_to_connnect_to = message.author.voice.channel
                     voice_object = await channel_to_connnect_to.connect()
